@@ -103,6 +103,7 @@ enum {
         STOPPED,
         EXITED,
         DIED,
+        HOSTNAME_SELECTED,
         LAST_SIGNAL
 };
 
@@ -155,14 +156,20 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
         if (launch_environment->priv->x11_authority_file != NULL)
                 g_hash_table_insert (hash, g_strdup ("XAUTHORITY"), g_strdup (launch_environment->priv->x11_authority_file));
 
-        if (launch_environment->priv->session_mode != NULL)
+        if (launch_environment->priv->session_mode != NULL) {
                 g_hash_table_insert (hash, g_strdup ("GNOME_SHELL_SESSION_MODE"), g_strdup (launch_environment->priv->session_mode));
 
-        /* Inital setup needs gvfs for fetching remote avatars. */
-        if (strcmp (launch_environment->priv->session_mode, INITIAL_SETUP_SESSION_MODE) != 0) {
-                g_hash_table_insert (hash, g_strdup ("GVFS_DISABLE_FUSE"), g_strdup ("1"));
-                g_hash_table_insert (hash, g_strdup ("GIO_USE_VFS"), g_strdup ("local"));
-                g_hash_table_insert (hash, g_strdup ("GVFS_REMOTE_VOLUME_MONITOR_IGNORE"), g_strdup ("1"));
+		if (strcmp (launch_environment->priv->session_mode, INITIAL_SETUP_SESSION_MODE) != 0) {
+			/* gvfs is needed for fetching remote avatars in the initial setup. Disable it otherwise. */
+			g_hash_table_insert (hash, g_strdup ("GVFS_DISABLE_FUSE"), g_strdup ("1"));
+			g_hash_table_insert (hash, g_strdup ("GIO_USE_VFS"), g_strdup ("local"));
+			g_hash_table_insert (hash, g_strdup ("GVFS_REMOTE_VOLUME_MONITOR_IGNORE"), g_strdup ("1"));
+
+			/* The locked down dconf profile should not be used for the initial setup session.
+			 * This allows overridden values from the user profile to take effect.
+			 */
+			g_hash_table_insert (hash, g_strdup ("DCONF_PROFILE"), g_strdup ("gdm"));
+		}
         }
 
         g_hash_table_insert (hash, g_strdup ("LOGNAME"), g_strdup (launch_environment->priv->user_name));
@@ -197,7 +204,6 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
         g_hash_table_insert (hash, g_strdup ("PATH"), g_strdup (g_getenv ("PATH")));
 
         g_hash_table_insert (hash, g_strdup ("RUNNING_UNDER_GDM"), g_strdup ("true"));
-        g_hash_table_insert (hash, g_strdup ("DCONF_PROFILE"), g_strdup ("gdm"));
 
         return hash;
 }
@@ -262,6 +268,15 @@ on_session_died (GdmSession           *session,
         g_signal_emit (G_OBJECT (launch_environment), signals [DIED], 0, signal_number);
 }
 
+static void
+on_hostname_selected (GdmSession               *session,
+                      const char               *hostname,
+		      GdmLaunchEnvironment     *launch_environment)
+{
+        g_debug ("GdmSession: hostname selected: %s", hostname);
+        g_signal_emit (launch_environment, signals [HOSTNAME_SELECTED], 0, hostname);
+}
+
 static void
 on_conversation_started (GdmSession           *session,
                          const char           *service_name,
@@ -408,6 +423,11 @@ gdm_launch_environment_start (GdmLaunchEnvironment *launch_environment)
                                  G_CALLBACK (on_session_died),
                                  launch_environment,
                                  0);
+        g_signal_connect_object (launch_environment->priv->session,
+                                 "hostname-selected",
+                                 G_CALLBACK (on_hostname_selected),
+                                 launch_environment,
+                                 0);
 
         gdm_session_start_conversation (launch_environment->priv->session, "gdm-launch-environment");
         gdm_session_select_program (launch_environment->priv->session, launch_environment->priv->command);
@@ -806,6 +826,18 @@ gdm_launch_environment_class_init (GdmLaunchEnvironmentClass *klass)
                               G_TYPE_NONE,
                               1,
                               G_TYPE_INT);
+
+        signals [HOSTNAME_SELECTED] =
+                g_signal_new ("hostname-selected",
+                              G_OBJECT_CLASS_TYPE (object_class),
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (GdmLaunchEnvironmentClass, hostname_selected),
+                              NULL,
+                              NULL,
+                              g_cclosure_marshal_VOID__STRING,
+                              G_TYPE_NONE,
+                              1,
+                              G_TYPE_STRING);
 }
 
 static void
